#ifndef RUBYSPEC_CAPI_JRUBY_H
#define RUBYSPEC_CAPI_JRUBY_H

/* #undef any HAVE_ defines that JRuby does not have. */
#undef HAVE_RB_DEFINE_HOOKED_VARIABLE
#undef HAVE_RB_DEFINE_VARIABLE

#undef HAVE_RB_EXEC_RECURSIVE

#endif
